@@ -29,7 +29,7 @@ use Promises;
 =cut
 
 use vars '$VERSION';
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 extends 'CORION::Apache::Tika';
 
@@ -57,7 +57,7 @@ has fh => (
 
 has connection_class => (
     is => 'ro',
-    default => 'Apache::Tika::Connection::AEHTTP',
+    default => 'CORION::Apache::Tika::Connection::AEHTTP',
 );
 
 has ua => (
